@@ -1,3 +1,32 @@
+# Copyright (c) 2021-2022, InterDigital Communications, Inc
+# All rights reserved.
+
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted (subject to the limitations in the disclaimer
+# below) provided that the following conditions are met:
+
+# * Redistributions of source code must retain the above copyright notice,
+#   this list of conditions and the following disclaimer.
+# * Redistributions in binary form must reproduce the above copyright notice,
+#   this list of conditions and the following disclaimer in the documentation
+#   and/or other materials provided with the distribution.
+# * Neither the name of InterDigital Communications, Inc nor the names of its
+#   contributors may be used to endorse or promote products derived from this
+#   software without specific prior written permission.
+
+# NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE GRANTED BY
+# THIS LICENSE. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+# CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
+# NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
+# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
+# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
+# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
+# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
+# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
 import warnings
 
 from typing import Any, Callable, List, Optional, Tuple, Union
@@ -452,10 +481,11 @@ class EntropyBottleneck(EntropyModel):
             # Compute inverse permutation
             inv_perm = np.arange(len(x.shape))[np.argsort(perm)]
         else:
+            raise NotImplementedError()
             # TorchScript in 2D for static inference
             # Convert to (channels, ... , batch) format
-            perm = (1, 2, 3, 0)
-            inv_perm = (3, 0, 1, 2)
+            # perm = (1, 2, 3, 0)
+            # inv_perm = (3, 0, 1, 2)
 
         x = x.permute(*perm).contiguous()
         shape = x.size()
@@ -472,8 +502,9 @@ class EntropyBottleneck(EntropyModel):
             if self.use_likelihood_bound:
                 likelihood = self.likelihood_lower_bound(likelihood)
         else:
+            raise NotImplementedError()
             # TorchScript not yet supported
-            likelihood = torch.zeros_like(outputs)
+            # likelihood = torch.zeros_like(outputs)
 
         # Convert back to input tensor shape
         outputs = outputs.reshape(shape)
@@ -572,7 +603,7 @@ class GaussianConditional(EntropyModel):
 
     def _standardized_cumulative(self, inputs: Tensor) -> Tensor:
         half = float(0.5)
-        const = float(-(2 ** -0.5))
+        const = float(-(2**-0.5))
         # Using the complementary error function maximizes numerical precision.
         return half * torch.erfc(const * inputs)
 
