@@ -39,6 +39,7 @@ from torch.cuda import amp
 
 from compressai.entropy_models import GaussianConditional
 from compressai.layers import QReLU
+from compressai.ops import quantize_ste
 from compressai.registry import register_model
 
 from ..google import CompressionModel, get_scale_table
@@ -48,7 +49,6 @@ from ..utils import (
     gaussian_blur,
     gaussian_kernel2d,
     meshgrid2d,
-    quantize_ste,
     update_registered_buffers,
 )
 
